@@ -16,6 +16,7 @@
 
 #include <fstream>
 #include <sstream>
+#include <streambuf>
 #include <string>
 
 #include <bsoncxx/builder/stream/document.hpp>
@@ -34,10 +35,12 @@
 #include <mongocxx/options/client.hpp>
 #include <mongocxx/options/client_encryption.hpp>
 #include <mongocxx/options/data_key.hpp>
+#include <mongocxx/read_concern.hpp>
 #include <mongocxx/test/spec/monitoring.hh>
 #include <mongocxx/test_util/client_helpers.hh>
 #include <mongocxx/uri.hpp>
 #include <mongocxx/write_concern.hpp>
+#include <third_party/catch/include/helpers.hpp>
 
 namespace {
 const auto kLocalMasterKey =
@@ -74,12 +77,14 @@ using namespace mongocxx;
 // Takes a path relative to the ENCRYPTION_TESTS_PATH variable, with leading '/'.
 bsoncxx::document::value _doc_from_file(stdx::string_view sub_path) {
     char* encryption_tests_path = std::getenv("ENCRYPTION_TESTS_PATH");
-    REQUIRE(encryption_tests_path);
+    std::string path{encryption_tests_path};
+    if (path.back() == '/') {
+        path.pop_back();
+    }
 
-    std::string path = std::string(encryption_tests_path) + sub_path.data();
-    CAPTURE(path);
+    std::string full_path = path + sub_path.data();
 
-    std::ifstream file{path};
+    std::ifstream file{full_path};
     REQUIRE(file);
 
     std::string file_contents((std::istreambuf_iterator<char>(file)),
@@ -210,7 +215,7 @@ void run_datakey_and_double_encryption(Callable create_data_key,
     // Expect that exactly one document is returned with the correct "masterKey.provider"
     std::size_t i = 0;
     for (auto&& doc : cursor) {
-        REQUIRE(doc["masterKey"]["provider"].get_string().value == provider);
+        REQUIRE(doc["masterKey"]["provider"].get_utf8().value == provider);
         i++;
     }
 
@@ -255,7 +260,7 @@ void run_datakey_and_double_encryption(Callable create_data_key,
     REQUIRE(res);
     auto decrypted_bson_val = res->view()["value"];
     REQUIRE(decrypted_bson_val.type() == bsoncxx::type::k_utf8);
-    REQUIRE(decrypted_bson_val.get_string().value == stdx::string_view{"hello there"});
+    REQUIRE(decrypted_bson_val.get_utf8().value == stdx::string_view{"hello there"});
 
     // 3. Call client_encryption.encrypt() with the value "hello there", the algorithm
     // AEAD_AES_256_CBC_HMAC_SHA_512-Deterministic, and the key_alt_name of provider_altname
@@ -819,11 +824,11 @@ void _run_corpus_test(bool use_schema_map) {
         // allowed is a boolean indicating whether the encryption for the given parameters is
         // permitted.
         // value is the value to be tested.
-        auto kms = subdoc["kms"].get_string().value;
-        auto type = subdoc["type"].get_string().value;
-        auto algo = subdoc["algo"].get_string().value;
-        auto method = subdoc["method"].get_string().value;
-        auto identifier = subdoc["identifier"].get_string().value;
+        auto kms = subdoc["kms"].get_utf8().value;
+        auto type = subdoc["type"].get_utf8().value;
+        auto algo = subdoc["algo"].get_utf8().value;
+        auto method = subdoc["method"].get_utf8().value;
+        auto identifier = subdoc["identifier"].get_utf8().value;
         auto allowed = subdoc["allowed"].get_bool().value;
         auto to_encrypt = subdoc["value"].get_value();
 
@@ -933,7 +938,7 @@ void _run_corpus_test(bool use_schema_map) {
         auto subdoc_val = ele.get_document();
         auto subdoc = subdoc_val.view();
 
-        auto algo = subdoc["algo"].get_string().value;
+        auto algo = subdoc["algo"].get_utf8().value;
         auto allowed = subdoc["allowed"].get_bool().value;
         auto value = subdoc["value"].get_value();
 
